package com.test.subject;

import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.plugin.*;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.osgi.framework.BundleContext;
import java.util.*;

/**
 * The main plugin class to be used in the desktop.
 */
public class SubjectEditorPlugin extends AbstractUIPlugin {

    final public static String PLUGIN_ID = "SubjectEditor";

    //The shared instance.
    private static SubjectEditorPlugin plugin;

    //Resource bundle.
    private ResourceBundle resourceBundle;

    public SubjectEditorPlugin(IPluginDescriptor descriptor) {
        super(descriptor);
    }

    /**
     * The constructor.
     */
    public SubjectEditorPlugin() {
        super();
        plugin = this;
    }

    /**
     * This method is called upon plug-in activation
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
        plugin = null;
        resourceBundle = null;
    }

    /**
     * Returns the shared instance.
     */
    public static SubjectEditorPlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the string from the plugin's resource bundle,
     * or 'key' if not found.
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = SubjectEditorPlugin.getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * Returns the plugin's resource bundle,
     */
    public ResourceBundle getResourceBundle() {
        try {
            if (resourceBundle == null)
                resourceBundle = ResourceBundle.getBundle("com.test.subject.SubjectEditorPluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
        return resourceBundle;
    }

    /**
     * Returns an image descriptor for the image file at the given
     * plug-in relative path.
     *
     * @param path the path
     * @return the image descriptor
     */
    public static ImageDescriptor getImageDescriptor(String path) {
        return AbstractUIPlugin.imageDescriptorFromPlugin("SubjectEditor", path);
    }

    /**
     * עͼ
     */
    protected void initializeImageRegistry(ImageRegistry reg) {
        super.initializeImageRegistry(reg);
        reg.put(IConstants.IMG_FOLDER, imageDescriptorFromPlugin(PLUGIN_ID, "icons/folder.gif"));
        reg.put(IConstants.IMG_FILE, imageDescriptorFromPlugin(PLUGIN_ID, "icons/file.gif"));
    }

    public static Image getImage(String symbolicName) {
        return getDefault().getImageRegistry().get(symbolicName);
    }

}
